.. _api:

===
API
===

.. module:: vcspull

.. automodule:: vcspull.util
   :members:
   :inherited-members:
   :show-inheritance:

.. automodule:: vcspull.repo

    .. autoclass:: Repo
        :members:
        :inherited-members:
        :show-inheritance:

    .. autoclass:: vcspull.repo.base.RepoLoggingAdapter
        :members:
        :show-inheritance:

    .. autoclass:: vcspull.repo.base.BaseRepo
        :members:
        :show-inheritance:

    .. autoclass:: vcspull.repo.git.GitRepo
        :members:
        :show-inheritance:

    .. autoclass:: vcspull.repo.hg.MercurialRepo
        :members:
        :show-inheritance:

    .. autoclass:: vcspull.repo.svn.SubversionRepo
        :members:
        :show-inheritance:
